@@ -32,6 +32,7 @@ import asyncio
 import json
 import logging
 import pathlib
+import sys
 import traceback
 import typing as t
 
@@ -105,7 +106,7 @@ class YouTubeBot(OAuthMixin):
 
     @property
     def access_token(self) -> str | None:
-        return t.cast(str | None, self.oauth_tokens.get("access_token", None))
+        return self.oauth_tokens.get("access_token", None)  # type: ignore
 
     @property
     def platform(self) -> str:
@@ -140,7 +141,7 @@ class YouTubeBot(OAuthMixin):
         if err:
             raise HTTPError(err["code"], err["errors"][0]["message"])
 
-        return t.cast(dict[str, t.Any], data)
+        return data  # type: ignore
 
     async def poll_for_messages(self) -> None:
         page_token = ""  # nosec: B105 false positive
@@ -214,7 +215,10 @@ class YouTubeBot(OAuthMixin):
     ) -> None:
         log.info("\33[1mNow starting bot!\33[0m")
 
-        self._loop = asyncio.new_event_loop()
+        if sys.version_info >= (3, 10):
+            self._loop = asyncio.new_event_loop()
+        else:
+            self._loop = asyncio.get_event_loop()
 
         try:
             # Create session.
